class PNGRenderer():
    def __init__(self):
        raise NotImplementedError()
